#
# Function to determine if we need a fixpack upgrade. We do this based
# on the current version and the requested version
#
Puppet::Functions.create_function('mq_install::fixpack_upgrade') do
  #
  # See the file "LICENSE" for the full license governing this code.
  #
  #
  # @param current_version The currently installed fixpack version.
  # @param requested_version The requested fixpack version.
  # @return If current_version is lower than the requested version return true. Else false
  #
  dispatch :fixpack_upgrade do
    required_param 'String',  :current_version
    required_param 'String',  :requested_version
    return_type 'Boolean'
  end

  def fixpack_upgrade(current_version, requested_version)
    return true if current_version == 'not-installed'

    current_major, current_minor, _, current_patch_level = current_version.split('.')
    requested_major, requested_minor, _, requested_patch_level = requested_version.split('.')

    fail 'Incompatible MQ versions specified for fixpack. Major and minor versions need to be same' if current_major != requested_major || current_minor != requested_minor

    current_patch_level.to_i < requested_patch_level.to_i
  end
end
