#
# Function to determine if we are changing to version with a different major or minor version.
#
Puppet::Functions.create_function('mq_install::version_upgrade') do
  #
  # See the file "LICENSE" for the full license governing this code.
  #
  #
  # @param current_version The currently installed MQ version.
  # @param requested_version The requested MQ version.
  # @return If current_version is higher major version than the requested version return true. Else false
  #
  dispatch :version_upgrade do
    required_param 'String',  :current_version
    required_param 'String',  :requested_version
    return_type 'Boolean'
  end

  def version_upgrade(current_version, requested_version)
    return false if current_version == 'not-installed'

    current_major, current_minor, = current_version.split('.')
    requested_major, requested_minor, = requested_version.split('.')

    fail "MQ doesn't support a downgrade on running queue managers" if current_major > requested_major || current_minor > requested_minor

    return true if requested_major != current_major
    return true if requested_minor != current_minor

    false
  end
end
