#
# mq_install::internal::mq_packages
#
# @summary This is an internal API.
# Please do not use this.
#
# @param [Array[String[1]]] packages
#    
#    The packages that are selected
#
# @param [String[1]] source_location
#    The location of the MQ software.
#    Here is an example on how to use this:
#        class { '::mq_install::...':
#          ...
#          source_location => '/software',
#          ...
#        }
#
#
# See the file "LICENSE" for the full license governing this code.
#
define mq_install::internal::mq_packages(
  Array[String[1]] $packages,
  String[1]        $service_window,
  String[1]        $source_location,
)
{
  if $caller_module_name != $module_name {
    fail("Use of private class ${name} by ${caller_module_name} not supported.")
  }
  $version = $title

  if $service_window == 'INSTALL_ONLY' {
    $service_schedule  = undef
  } else {
    $service_schedule  = 'MQ_SOFTWARE_SERVICE_WINDOW'
  }

  if 'MQSeriesFTBase' in $packages {
    $base_packages = [
      'MQSeriesRuntime',
      'MQSeriesJRE',
      'MQSeriesJava',
      'MQSeriesServer',
      'MQSeriesFTBase',
      ]
  } else {
    $base_packages = [
      'MQSeriesRuntime',
      'MQSeriesJRE',
      'MQSeriesJava',
      'MQSeriesServer',
      ]
  }

  $additional_packages = $packages - $base_packages

  easy_type::debug_evaluation() # Show local variable on extended debug

  $base_packages.each | $package| {
    package {"${package}-${version}":
      ensure   => $version,
      provider => 'rpm',
      source   => "${source_location}/${package}-${version}.x86_64.rpm",
      schedule => $service_schedule,
    }
  }

  $additional_packages.each | $package| {
    package {"${package}-${version}":
      ensure   => $version,
      provider => 'rpm',
      source   => "${source_location}/${package}-${version}.x86_64.rpm",
      schedule => $service_schedule,
    }
  }
}
