#
# mq_install::internal::mq_stop
#
# @summary This is an internal API.
# Please do not use this.
#
# @param [Variant[Enum['on_failure'], Boolean]] logoutput
#    If you want to see the output of the `exec` resources in the type, you can set this value to `true`.
#    The default is `on_failure`.
#    Here is an example on how to use this:
#        class { '::mq_install::...':
#          ...
#          logoutput => true,
#          ...
#        }
#
#
# See the file "LICENSE" for the full license governing this code.
#
class mq_install::internal::mq_stop(
  Variant[Enum['on_failure'], Boolean] $logoutput = 'on_failure',    # Output of the execs
)
{
  easy_type::debug_evaluation() # Show local variable on extended debug

  if defined($caller_module_name) and $caller_module_name != $module_name {
    fail("Use of private class ${name} by ${caller_module_name} not supported.")
  }

  case $::kernel {
    'Linux', 'SunOS': { $path = '/opt/mqm/bin'}
    'AIX': { $path = '/usr/mqm/bin' }
    default: { fail "Internal error. Unsupported kernel ${::kernel}"}
  }

  #
  # Stop all running MQ managers
  #
  $running_managers = mq_install::running_managers()
  $running_managers.each |$manager| {
    if $::os['family'] == 'RedHat' and Integer($::os['release']['major']) >= 7  {
      $command = "/bin/systemctl stop mq@${manager}"
      $user    = 'root'
    } else {
      $command = "${path}/endmqm -p ${manager}"
      $user    = 'mqm'
    }
    exec { "Stop MQ manager ${manager}":
      user      => $user,
      command   => $command,
      schedule  => 'MQ_SOFTWARE_SERVICE_WINDOW',
      logoutput => $logoutput,
    }
  }
}
