#
# mq_install::os
#
# @summary Deprecated; Please the ibm_profile module.
# **This class is deprecated.** The best thing, is to use the [ibm_profile module](https://forge.puppet.com/modules/enterprisemodules/ibm_profile). The [ibm_profile module](https://forge.puppet.com/modules/enterprisemodules/ibm_profile) contains several steps that you can use to customize your OS setup as needed for MQ.
# 
# ## Old documentation
# 
# The `mq_install::os` defined type is a convenience class for adding the MQ users and setting the MQ OS requirements on your system.
# 
# class mq_install::os(
#   Easy_type::Password $mqm_password,
# )
# 
# Here is an example on how to use it:
# 
# ``` puppet
# class { 'mq_install::os':
#   mqm_password    => Sensitive('verysecret'),
# }
# ```
#
# @param [Easy_type::Password] mqm_password
#    The password to be used for the `mqm` user.
#    The default is the same as the username.
#    Here is an example on how to use this:
#        class { '::mq_install::os':
#          ...
#          mqm_password => Sensitive('secret'),
#          ...
#        }
#
# @param [Boolean] managehome
#    Allows you to specify whether you want to manage the MQM users home dir.
#    By default this is set to true and it will create a home directory for
#    the MQM user named '/var/mqm'.
#    When you want to use an other folder, set the value of `managehome` to false
#    and create your own links from '/var/mqm' to the directories you want.
#    Here is an example on how to use this:
#        class { '::mq_install::os':
#          ...
#          managehome => false,
#          ...
#        }
#
#
# See the file "LICENSE" for the full license governing this code.
#
class mq_install::os(
  Integer $nofile,
  Integer $nproc,
  Integer $shmall,
  Integer $shmmax,
  Integer $shmmni,
  Integer $overcommit_memory,
  Integer $overcommit_ratio,
  Integer $threads_max,
  Integer $pid_max,
  Integer $file_max,
  Easy_type::Password $mqm_password,
  Boolean $managehome        = true,
)
{
  deprecation ('mq_install::os', "The 'mq_install::os' class is deprecated. Use 'ibm_profile::mq_machine' instead for MQ OS management.")

  mq_install { 'mq_install::os': }


  if $::osfamily == 'windows' {
    # user{ 'mqm':
    #   ensure     => 'present',
    #   password   => $mqm_password,
    #   home       => 'C:\\Users\\mqm',
    #   shell      => 'cmd',
    #   comment    => 'This user was created by Puppet',
    #   # groups     => ['mqm'],
    #   managehome => $managehome,
    # }
    #TODO: finish kernels and limits
  }
  else
  {
    group {'mqm':
      ensure => 'present',
    }
    user{ 'mqm':
      ensure     => 'present',
      password   => $mqm_password.unwrap,
      home       => '/var/mqm',
      shell      => '/bin/bash',
      comment    => 'This user was created by Puppet',
      groups     => ['mqm'],
      managehome => $managehome,
    }

    limits::limits{'mqm/nofile': both => $nofile,}
    limits::limits{'mqm/nproc': both => $nproc,}
    class { 'limits':
      manage_limits_d_dir => false,
    }
    contain limits
    sysctl { 'kernel.shmall':         ensure => present, value  => $shmall,}
    sysctl { 'kernel.shmmax':         ensure => present, value  => $shmmax,}
    sysctl { 'kernel.shmmni':         ensure => present, value  => $shmmni,}
    sysctl { 'vm.overcommit_memory':  ensure => present, value  => $overcommit_memory,}
    sysctl { 'vm.overcommit_ratio':   ensure => present, value  => $overcommit_ratio,}
    sysctl { 'kernel.threads-max':    ensure => present, value  => $threads_max,}
    sysctl { 'kernel.pid_max':        ensure => present, value  => $pid_max,}
    sysctl { 'fs.file-max':           ensure => present, value  => $file_max,}
  }
}
