#!/opt/puppetlabs/puppet/bin/ruby
#
# See the file "LICENSE" for the full license governing this code.
#
require 'json'
require 'open3'
require 'puppet'

def status_for_qm(queue_manager)
  puts `systemctl status -l mq@#{queue_manager}`
end

def linux_implementation(queue_manager)
  if queue_manager == '*'
    queue_managers = `su - mqm -c "/opt/mqm/bin/dspmq"`.scan(/QMNAME\((.*?)\)/).flatten
    queue_managers.each { |qm| status_for_qm(qm) }
  else
    status_for_qm(queue_manager)
  end
end

def solaris_implementation(queue_manager)
  puts `/etc/init.d/mq status #{queue_manager}`
end

params = JSON.parse($stdin.read)
qm     = params.fetch('queue_manager') { '*' }

begin
  kernel = Facter.value(:kernel)
  case kernel
  when 'Linux'
    linux_implementation(qm)
  when 'SunOS'
    solaris_implementation(qm)
  else
    fail "#{kernel} is not (yet) supported"
  end
  exit 0
rescue Puppet::Error => e
  puts({ :status => 'failure', :error => e.message }.to_json)
  exit 1
end
